/*
 * Copyright (c) 2009,2010,2013 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _IVMOBCONST_H
#define _IVMOBCONST_H

#define IVMOB_TICKS_PERIOD 5
#define IVMOB_SEC_PERIOD 0.050

#define IVMOB_DIST_TO_CONTROLLED_POINT 0.0

/* Default uncertainties */
#define IVMOB_VAR_XX	0.001
#define IVMOB_VAR_YY	0.001
#define IVMOB_VAR_TT	0.0001
#define IVMOB_VAR_QCOEFF	0.05

#define IVMOB_DEFAULT_WHEEL_RADIUS 0.265
#define IVMOB_DEFAULT_WHEEL_TRACK_WIDTH 0.626
#define IVMOB_DEFAULT_MAXIMUM_VELOCITY 2
#define IVMOB_DEFAULT_MAXIMUM_YAW_RATE 0.62

#define IVMOB_DEFAULT_MAXIMUM_ACCEL 1.5
#define IVMOB_DEFAULT_MAXIMUM_YAW_ACCEL 0.62 /* XXX */

/* Odometry z correction */
#define IVMOB_ZODOCOR_ACCTHRES 0.75 /* acceleration threshold (factor of IVMOB_ACCEL_LIN_MAX) to disable z update (m/s2) */
#define IVMOB_ZODOCOR_LATENCY  4.0  /* how long it is disabled after last accel above threshold (s) */
#define IVMOB_ZODOCOR_AVGPITCHSIZE 5 /* number of pitch samples to average for value to use when update is disabled */
#define IVMOB_ZODOCOR_AVGVELSIZE 5 /* number of pitch samples to average for value to use when update is disabled */

/* Control Params */
#define IVMOB_KP_LONGIT	2.
#define IVMOB_KI_LONGIT	1.

#define IVMOB_KP_TRANSV	10.
#define IVMOB_KI_TRANSV	6.

#define IVMOB_KP_ANG		2.
#define IVMOB_KI_ANG		2.

/* gyro asserv params */
#define IVMOB_DELAY_GYRO_OMEGA	0.3 /* delay between command and measure, in seconds */
#define IVMOB_KP_GYRO_OMEGA	2.0
#define IVMOB_KP_GYRO_THETA	10.0
#define IVMOB_KI_GYRO_THETA	2.0

/* max errors */
#define IVMOB_LONGIT_MAX_GAP	0.5
#define IVMOB_TRANSV_MAX_GAP	0.5
#define IVMOB_ANG_MAX_GAP	0.5

#define IVMOB_LONGIT_ERROR_MAX	0.5
#define IVMOB_TRANSV_ERROR_MAX	0.5
#define IVMOB_ANG_ERROR_MAX	0.5

#define IVMOB_LONGIT_MAX_ERR_SUM	1.0
#define IVMOB_TRANSV_MAX_ERR_SUM	1.0
#define IVMOB_ANG_MAX_ERR_SUM		1.0

#endif
